//===============================================================================
// This do file looks at the results from the scenarios investigating the effect
// of the distribution of the unobserved variable
//
// I will recover from these scenarios the following elements:
//
// ==> the change in effect of father's education between transitions 1 and 2 and
//     transition 2 and 3
//
// ==> The change in effect of father's education for a decade increase in cohort
//
// ==> One sided p-values of the test of the null-hypothesis that these changes 
//     are 0 or larger, i.e. we find negative trends if we reject the null 
//
// These elements will first be stored in the current dataset
// At the botom of this do-file these variables will be turned into the graphs 
// that were shown in the paper
//
// Tricks used for getting one-sided test are explained here:
// http://www.stata.com/support/faqs/stat/oneside.html
//===============================================================================

run "dataprep"

//===============================================================================
// create variable identifying the scenario
//===============================================================================

// the scenarios are not equally spaced, as this way I can graph 
// distribution that are conceptually close together as a "group"
gen     dist = 1  in 1
replace dist = 3  in 2
replace dist = 4  in 3
replace dist = 6  in 4
replace dist = 7  in 5
replace dist = 9  in 6
replace dist = 10 in 7


label define dist 1  "normal"                     ///
                  3  "discrete (.25 .25 .25 .25)" ///
                  4  "uniform"                    ///
				  6  "discrete (.1 .6 .2 .1)"     ///
				  7  "discrete (.1 .6 .2 0 .1)"   ///
				  9  "discrete (.1 .2 .6 .1)"     ///
				  10 "discrete (.1 0 .2 .6 .1)"   
label value dis dist

//================================================================================
// Study effect of the distribution of the unobserved variable  
// on changes in effects of father's education over transitions
//================================================================================

local k = 1	
// the "reference" is the scenario with a normal distribution, which is stored as the fifth model in sens.ster
est use "sens", number(5)

// coh = 6 for the cohort born in 1960, so
// [#]_b[fed] + [#]_b[_fed_X_coh]*6
// is the effect of fed for that cohort in equation #
local diff1 "[#2]_b[fed] + [#2]_b[_fed_X_coh]*6 - [#1]_b[fed] - [#1]_b[_fed_X_coh]*6"
local diff2 "[#3]_b[fed] + [#3]_b[_fed_X_coh]*6 - [#2]_b[fed] - [#2]_b[_fed_X_coh]*6"

test `diff1' = 0
local sign = sign(`diff1')
gen double p_tr_1 =  normal(`sign'*sqrt(r(chi2))) in `k' // one-sided p-value
gen b_tr_1 = 100*(exp(`diff1') - 1) in `k'               // % change in odds ratio from trans. 1 to trans. 2

test `diff2' = 0
local sign = sign(`diff2')
gen double p_tr_2 =  normal(`sign'*sqrt(r(chi2))) in `k' // one-sided p-value
gen b_tr_2 = 100*(exp(`diff2') - 1) in `k'               // % change in odds ratio from trans. 2 to trans. 3

local k = `k' + 1

forvalues i = 1/6 {
	est use "sens_dist", number(`i')
	
	test `diff1' = 0
	local sign = sign(`diff1')
	replace p_tr_1 =  normal(`sign'*sqrt(r(chi2))) in `k' // one-sided p-value
	replace b_tr_1 = 100*(exp(`diff1')-1) in `k'          // % change in odds ratio from trans. 1 to trans. 2
	
	test `diff2' = 0
	local sign = sign(`diff2')
	replace p_tr_2 =  normal(`sign'*sqrt(r(chi2))) in `k' // one-sided p-value
	replace b_tr_2 = 100*(exp(`diff2') - 1) in `k'        // % change in odds ratio from trans. 2 to trans. 3
	
	local k = `k' + 1
}	


//================================================================================
// Study effect of the distribution of the unobserved variable  
// on changes in effects of father's education over cohorts
//================================================================================
local k = 1

est use "sens", number(5)
forvalues j = 1/3 {
	test [#`j']_b[_fed_X_coh]
	local sign = sign([#`j']_b[_fed_X_coh])
	gen double p_coh_`j' =  normal(`sign'*sqrt(r(chi2))) in `k' // one-sided p-value
	gen b_coh_`j' = 100*(exp([#`j']_b[_fed_X_coh])-1) in `k'    // % change in odds ratio for decade change in cohort 
}

local k = `k' + 1
forvalues i = 1/6 {
	est use "sens_dist", number(`i')
	forvalues j = 1/3 {
		test [#`j']_b[_fed_X_coh]
		local sign = sign([#`j']_b[_fed_X_coh])
		replace p_coh_`j' =  normal(`sign'*sqrt(r(chi2))) in `k'      // one-sided p-value
		replace b_coh_`j' = 100*(exp([#`j']_b[_fed_X_coh])-1) in `k'  // % change in odds ratio for decade change in cohort
	}
	local k = `k' + 1
}

//===================
// Graph the results
//==================

// change in effect of father's education over transitions
// size of trend
twoway scatter dist b_tr_1, msymbol(Oh) || ///
       scatter dist b_tr_2, msymbol(O) ///
    ylab(1 3 4 6 7 9 10, val grid)         ///
	xtitle("% change in odds ratio" "per transition") ///
	ytitle("")                             /// 
	legend(order( 1 "transition 2 v." ///
	                "transition 1"    ///
				  2 "transition 3 v." ///
				    "transition 2" ) col(2)) ///
	xline(0, lcolor(gs10)) ///					
    name(tr_b, replace)

// p-value	
twoway scatter dist p_tr_1, msymbol(Oh) || ///
       scatter dist p_tr_2, msymbol(O) xscale(log) ///
    ylab(1 3 4 6 7 9 10, val grid)                    ///
    xlab(10e-60 "10{sup:-60}" 10e-40 "10{sup:-40}" 10e-20 "10{sup:-20}" 10e0 "10{sup:0}")  ///
	xline(.05, lcolor(gs10))                          ///
	text(2 .05 "{&alpha} = .05", placement(3) orientation(rvertical) ) ///
    xtitle("p-value" "(logarithmic scale)") ytitle("") ///
	legend(order( 1 "transition 2 v." ///
	                "transition 1"    ///
				  2 "transition 3 v." ///
				    "transition 2" ) col(2)) ///
	name(tr_p, replace)
grc1leg tr_b tr_p	
graph export "c:\mijn documenten\projecten\rssm\trend_trans_dist.eps", replace 

// change in effect of father's education over cohorts
// size of trend
twoway scatter dist b_coh_1, msymbol(Oh) || ///
       scatter dist b_coh_2, msymbol(O) mcolor(gs10) || ///
	   scatter dist b_coh_3, msymbol(O) mcolor(black) ///
    ylab(1 3 4 6 7 9 10, val grid)         ///
	xtitle("% change in odds ratio" "per decade") ///
	ytitle("")                             /// 
	legend(order( 1 "transition 1" ///
	              2 "transition 2" ///
				  3 "transition 3" ) ///
			col(2)) ///
	xline(0, lcolor(gs10)) ///
    name(coh_b, replace)

// p-value	
twoway scatter dist p_coh_1 , msymbol(Oh) || ///
       scatter dist p_coh_2 , msymbol(O) mcolor(gs10) || ///
	   scatter dist p_coh_3 , msymbol(O) mcolor(black) xscale(log) ///
    ylab(1 3 4 6 7 9 10, val grid)                    ///
    xlab(10e-20 "10{sup:-20}" 10e-10 "10{sup:-10}"  10e0 "10{sup:0}")  ///
    xline(.05, lcolor(gs10))         ///
	text(2 .05 "{&alpha} = .05", placement(3) orientation(rvertical) ) ///
    xtitle("p-value" "(logarithmic scale)") ytitle("") ///
	legend(order( 1 "transition 1" ///
	              2 "transition 2" ///
				  3 "transition 3" ) ///
			col(2)) ///
	name(coh_p, replace)
grc1leg coh_b coh_p	
graph export "trend_coh_dist.eps", replace 


exit

