//===============================================================================
// This do file looks at the results from the scenarios investigating the effect
// of changes in the amount of unobserved heterogeneity
//
// This do file requires that sd.do has been run
//
// I will recover from these scenarios the following elements:
//
// ==> the change in effect of father's education between transitions 1 and 2 and
//     transition 2 and 3
//
// ==> The change in effect of father's educaiton for a decade increase in cohort
//
// ==> One sided p-values of the test of the null-hypothesis that these changes 
//     are 0 or larger, i.e. we find negative trends if we reject the null 
//
// ==> The effects of father's education for different cohorts
// 
// These elements will first be stored in the current dataset
// At the botom of this do-file these variables will be turned into the graphs 
// that were shown in the paper
//
// Tricks used for getting one-sided test are explained here:
// http://www.stata.com/support/faqs/stat/oneside.html
//===============================================================================

run "dataprep"

//==============================================================================
// amount of unobserved heterogeneity as specified in scenario
//===============================================================================
gen sd = _n*.5 - .5 in 1/11  

//================================================================================
// Study effect of unobserved heterogeneity on changes in effects over transitions
//================================================================================
local k = 1	

// start with initial model (no unobserved heterogeneity
est restore null

// coh = 6 for the cohort born in 1960, so
// [#]_b[fed] + [#]_b[_fed_X_coh]*6
// is the effect of fed for that cohort in equation #
local diff1 "[#2]_b[fed] + [#2]_b[_fed_X_coh]*6 - [#1]_b[fed] - [#1]_b[_fed_X_coh]*6"
local diff2 "[#3]_b[fed] + [#3]_b[_fed_X_coh]*6 - [#2]_b[fed] - [#2]_b[_fed_X_coh]*6"

test `diff1' = 0
local sign = sign(`diff1')
gen double p_coh_1 =  normal(`sign'*sqrt(r(chi2))) in `k' // one-sided p-value
gen b_coh_1 = (exp(`diff1')-1)*100  in `k'               // % change in odds ratio from trans. 1 to trans. 2

test `diff2' = 0
local sign = sign(`diff2')
gen double p_coh_2 =  normal(`sign'*sqrt(r(chi2))) in `k' // one sided p-value
gen b_coh_2 = (exp(`diff2')-1)*100 in `k'               // % change in odds ratio from trans. 2 to trans. 3

local k = `k' + 1

// do the same for the subsequent scenarios
forvalues i = 1/10{
	est use "sens", number(`i')

	test `diff1' = 0
	local sign = sign(`diff1')
	replace p_coh_1 =  normal(`sign'*sqrt(r(chi2))) in `k'
	replace b_coh_1 = (exp(`diff1')-1)*100 in `k'

	test `diff2' = 0
	local sign = sign(`diff2')
	replace p_coh_2 =  normal(`sign'*sqrt(r(chi2))) in `k'
	replace b_coh_2 = (exp(`diff2')-1)*100 in `k'

	local k = `k' + 1
}	

//========================================================================================
// study effect of unobserved heterogeneity on estimates of IEOpp and changes over cohorts
//========================================================================================

// Look at the size of the effect of father's education, and the size of the change of this
// effect over cohorts
local k = 1
// start with null model
est restore null
forvalues j = 1/3 {
	gen eff_fed_`j'_0 = exp([#`j']_b[fed] + [#`j']_b[_fed_X_coh]*coh) // effect of father's education for different cohorts
	gen b_fed_`j' = (exp([#`j']_b[_fed_X_coh])-1)*100 in `k'          // % change in effect of father's education for a decade change in cohort 
}
// repeat for the other scenarios
local k = `k' + 1
forvalues i = 1/10{
	est use "sens", number(`i')
	forvalues j = 1/3 {
		gen eff_fed_`j'_`i' = exp([#`j']_b[fed] + [#`j']_b[_fed_X_coh]*coh) 
		replace b_fed_`j' = (exp([#`j']_b[_fed_X_coh])-1)*100 in `k'
	}
	local k = `k' + 1
}

// Look at the statistical test of whether the change in effect over cohorts >= 0
local k = 1
est restore null
forvalues j = 1/3 {
	test [#`j']_b[_fed_X_coh]
	local sign = sign([#`j']_b[_fed_X_coh])
	gen double p_fed_`j' =  normal(`sign'*sqrt(r(chi2))) in `k' // one-sided p-value
}

local k = `k' + 1
forvalues i = 1/10{
	est use "sens", number(`i')
	forvalues j = 1/3 {
		test [#`j']_b[_fed_X_coh]
		local sign = sign([#`j']_b[_fed_X_coh])
		replace p_fed_`j' =  normal(`sign'*sqrt(r(chi2))) in `k'
	}
	local k = `k' + 1
}

//===================
// Graph the results
//==================

// Graph size of effect of father's education over cohorts for scenarios
// no unobserved heterogeneity, sd==2.5, sd==3


// this is a variation on the trick proposed in Royston, Patrick (2005)
// Stata tip 19: A way to leaner, faster graphs. The Stata Journal,
// 5(2), 279. http://www.stata-journal.com/article.html?article=gr0013
bys coh : gen byte mark = _n == 1

// Transition 1
twoway line eff_fed_1_0 eff_fed_1_5 eff_fed_1_10 coh if mark,  ///
    sort yscale(log) ylab(1 5 10 20 30 40) yscale(range(1 51)) ///
	ytitle("odds ratio (logarithmic scale)")                   ///
	title("first transition")                                  ///
	xlab( 1 `""1901" "1910""'                                  ///
	      3 `""1921" "1930""'                                  ///
		  5 `""1941" "1950""'                                  ///
		  7 `""1961" "1970""')                                 ///
	xmtick(0(2)8)                                              ///
	xtitle("decade in which respondent was born")              ///
	text(3  1 "{&beta}{sub:u}= 0"  , alignment(bottom))        ///
	text(11 1 "{&beta}{sub:u}= 2.5", alignment(bottom))        ///
	text(45 1 "{&beta}{sub:u}= 5"  , alignment(bottom))        ///
	legend(off) name(first, replace)

// Transition 2	
twoway line eff_fed_2_0 eff_fed_2_5 eff_fed_2_10 coh if mark,  ///
    sort yscale(log) ylab(1 5 10 20 30 40) yscale(range(1 51)) ///
	ytitle("odds ratio (logarithmic scale)")                   ///
	title("second transition")                                 ///
	xlab( 1 `""1901" "1910""'                                  ///
	      3 `""1921" "1930""'                                  ///
		  5 `""1941" "1950""'                                  ///
		  7 `""1961" "1970""')                                 ///
	xmtick(0(2)8)                                              ///	  
	xtitle("decade in which respondent was born")              ///
	text(2.5 1 "{&beta}{sub:u}= 0"  , alignment(bottom))       ///
	text(7   1 "{&beta}{sub:u}= 2.5", alignment(bottom))       ///
	text(25  1 "{&beta}{sub:u}= 5"  , alignment(bottom))       ///
	legend(off) name(second, replace)

// transition 3	
twoway line eff_fed_3_0 eff_fed_3_5 eff_fed_3_10 coh if mark,  ///
    sort yscale(log) ylab(1 5 10 20 30 40) yscale(range(1 51)) ///
	ytitle("odds ratio (logarithmic scale)")                   ///
	title("third transition")                                  ///
	xlab( 1 `""1901" "1910""'                                  ///
	      3 `""1921" "1930""'                                  ///
		  5 `""1941" "1950""'                                  ///
		  7 `""1961" "1970""')                                 ///
	xmtick(0(2)8)                                              ///	  
	xtitle("decade in which respondent was born")              ///	  
	text(1.75 1 "{&beta}{sub:u}= 0"  , alignment(bottom))      ///
	text(5    1 "{&beta}{sub:u}= 2.5", alignment(bottom))      ///
	text(18   1 "{&beta}{sub:u}= 5"  , alignment(bottom))      ///
	legend(off) name(third, replace)	

graph combine first second third, ysize(6) iscale(*.75)        
graph export "ieopp.eps", replace 

// Graph trend in effect of father's education over cohorts
sort sd
// size of trend
twoway line b_fed_? sd if sd < ., ///
    ytitle("% change in odds ratio per decade") ///
	title("trend in effect of father's education") ///
	xtitle("{&beta}{sub:u}") ///
	legend(order( 1 "transition 1" ///
	              2 "transition 2" ///
				  3 "transition 3" ) ///
			col(2)) ///
	name(sd_coh_b, replace)

// p-value of test trend >= 0	
twoway line p_fed_* sd if sd < ., ///
    yscale(log range(.05 10e-15)) ///
	ylab(10e0 "10{sup:0}" 10e-5 "10{sup:-5}" 10e-10 "10{sup:-10}" 10e-15 "10{sup:-15}"  ) ///
	title("P-value of test of H{sub:0}: trend {&ge} 0") ///
	ytitle("p-value (logarithmic scale)") xtitle("{&beta}{sub:u}") yline(.05, lcolor(gs10)) ///
	text(.05 4.5 "{&alpha} = .05", placement(6) ) ///
	legend(order( 1 "transition 1" ///
	              2 "transition 2" ///
				  3 "transition 3" ) ///
			col(2)) ///
	name(sd_coh_p, replace)
	
grc1leg sd_coh_b sd_coh_p
graph export "trend_coh.eps", replace 	

// Graph trend in effect of father's education over transitions
// size of effect
twoway line b_coh_? sd, ///
    ytitle("% change in odds ratio per transition") ///
	title("trend in effect of father's education") ///
	legend(order( 1 "transition 2 v." ///
	                "transition 1"    ///
				  2 "transition 3 v." ///
				    "transition 2" ) col(2)) ///
	xtitle("{&beta}{sub:u}") name(sd_tr_b, replace)

// p-value of test trend >= 0	
twoway line p_coh_? sd, ///
    ytitle("p-value (logarithmic scale)") ///
	title("P-value of test of H{sub:0}: trend {&ge} 0") ///
	xtitle("{&beta}{sub:u}") ///
	legend(order( 1 "transition 2 v." ///
	                "transition 1"    ///
				  2 "transition 3 v." ///
				    "transition 2" ) col(2)) ///
	yscale(log range(5e-2 1e-5)) ///
	ylab(1 "10{sup:0}" 10e-10 "10{sup:-10}" 10e-20 "10{sup:-20}" 10e-30 "10{sup:-30}" ) ///
	text(.05 .5 "{&alpha} = .05", placement(12) ) ///
	yline(.05, lcolor(gs10))  name(sd_tr_p, replace)
	
grc1leg sd_tr_b sd_tr_p	
graph export "trend_trans.eps", replace 

