//===============================================================================
// This do file looks at the results from the scenarios investigating the effect
// of changes in the amount of unobserved heterogeneity over cohorts
//
// I will recover from these scenarios the following elements:
//
// ==> the change in effect of father's education between transitions 1 and 2 and
//     transition 2 and 3
//
// ==> The change in effect of father's education for a decade increase in cohort
//
// ==> One sided p-values of the test of the null-hypothesis that these changes 
//     are 0 or larger, i.e. we find negative trends if we reject the null 
//
// These elements will first be stored in the current dataset
// At the botom of this do-file these variables will be turned into the graphs 
// that were shown in the paper
//
// Tricks used for getting one-sided test are explained here:
// http://www.stata.com/support/faqs/stat/oneside.html
//===============================================================================
	
run "dataprep"

//==============================================================================
// the rate of change in the amount of unobserved heterogeneity over cohorts
// as specified in the scenarios
//===============================================================================
gen d_coh = -.4 + .1*_n in 1/7


//================================================================================
// Study effect of changes in unobserved heterogeneity over cohorts
// on changes in effects of father's education over transitions
//================================================================================
local k = 1	
est use "`h'sens_sd_coh", number(1)

// coh = 6 for the cohort born in 1960, so
// [#]_b[fed] + [#]_b[_fed_X_coh]*6
// is the effect of fed for that cohort in equation #
local diff1 "[#2]_b[fed] + [#2]_b[_fed_X_coh]*6 - [#1]_b[fed] - [#1]_b[_fed_X_coh]*6"
local diff2 "[#3]_b[fed] + [#3]_b[_fed_X_coh]*6 - [#2]_b[fed] - [#2]_b[_fed_X_coh]*6"

test `diff1' = 0
local sign = sign(`diff1')
gen double p_tr_1 =  normal(`sign'*sqrt(r(chi2))) in 1 // p-value for one sided test
gen b_tr_1 = 100*(exp(`diff1') - 1) in 1               // % change in effect of fed from transition 1 to transition 2

test `diff2' = 0
local sign = sign(`diff2')
gen double p_tr_2 =  normal(`sign'*sqrt(r(chi2))) in 1 // one-sided p-value
gen b_tr_2 = 100*(exp(`diff2') - 1) in 1               // % change in effect of fed form trans. 2 to trans. 3

forvalues i = 2/7 {
	est use "`h'sens_sd_coh", number(`i')
	
	test `diff1' = 0
	local sign = sign(`diff1')
	replace p_tr_1 =  normal(`sign'*sqrt(r(chi2))) in `i'
	replace b_tr_1 = 100*(exp(`diff1')-1) in `i'
	
	test `diff2' = 0
	local sign = sign(`diff2')
	replace p_tr_2 =  normal(`sign'*sqrt(r(chi2))) in `i'
	replace b_tr_2 = 100*(exp(`diff2') - 1) in `i'
}	

//================================================================================
// Study effect of changes in unobserved heterogeneity over cohorts
// on changes in effects of father's education over cohorts
//================================================================================
est use "`h'sens_sd_coh", number(1)
forvalues j = 1/3 {
	test [#`j']_b[_fed_X_coh]
	local sign = sign([#`j']_b[_fed_X_coh])
	gen double p_coh_`j' =  normal(`sign'*sqrt(r(chi2))) in 1
	gen b_coh_`j' = 100*(exp([#`j']_b[_fed_X_coh])-1) in 1
}

forvalues i = 2/7 {
	est use "`h'sens_sd_coh", number(`i')
	forvalues j = 1/3 {
		test [#`j']_b[_fed_X_coh]
		local sign = sign([#`j']_b[_fed_X_coh])
		replace p_coh_`j' =  normal(`sign'*sqrt(r(chi2))) in `i'
		replace b_coh_`j' = 100*(exp([#`j']_b[_fed_X_coh])-1) in `i'
	}
}

//===================
// Graph the results
//==================

// change in effect of father's education over transitions
// size of trend
twoway line b_tr_? d_coh, ///
    ytitle("% change in odds ratio per transition") ///
	title("trend in effect of father's education") ///
	xtitle("change in {&beta}{sub:u} per decade") ///
	legend(order( 1 "transition 2 v." ///
	                "transition 1"    ///
				  2 "transition 3 v." ///
				    "transition 2" ) col(2)) ///
	yline(0, lcolor(gs10)) ///
	name(delta_trans_b, replace)

// p-values	
twoway line p_tr_? d_coh, ///
    ytitle("p-value (logarithmic scale)") ///
	title("P-value of test of H{sub:0}: trend {&ge} 0") ///
	xtitle("change in {&beta}{sub:u} per decade" ) ///
	legend(order( 1 "transition 2 v." ///
	                "transition 1"    ///
				  2 "transition 3 v." ///
				    "transition 2" ) col(2)) ///
	yscale(log range(5e-2 1e-5)) ///
	ylab(10e0 "10{sup:0}" 10e-5 "10{sup:-5}"  10e-10 "10{sup:-10}" 10e-15 "10{sup:-15}" 10e-20 "10{sup:-20}" 10e-25 "10{sup:-25}") ///
	text(.05 .3 "{&alpha} = .05", placement(6) ) ///
	yline(.05, lcolor(gs10))  name(delta_trans_p, replace)

grc1leg delta_trans_b delta_trans_p	
graph export "trend_trans_coh.eps", replace 

// change in effect of father's education over cohorts
// size of trend
twoway line b_coh_? d_coh, ///
    ytitle("% change in odds ratio per decade") ///
	title("trend in effect of father's education") ///
	xtitle("change in {&beta}{sub:u} per decade") ///
	legend(order( 1 "transition 1" ///
	              2 "transition 2" ///
				  3 "transition 3" ) ///
			col(2)) ///
	name(delta_coh_b, replace)

// p-values
twoway line p_coh_? d_coh, ///
    ytitle("p-value (logarithmic scale)") ///
	title("P-value of test of H{sub:0}: trend {&ge} 0") ///
	xtitle("change in {&beta}{sub:u} per decade") ///
	legend(order( 1 "transition 1" ///
	              2 "transition 2" ///
				  3 "transition 3" ) ///
			col(2)) ///
	yscale(log range(1 10e-15)) ///
	ylab(10e0 "10{sup:0}" 10e-5 "10{sup:-5}"  10e-10 "10{sup:-10}" 10e-15 "10{sup:-15}" 10e-20 "10{sup:-20}" ) ///
	text(.05 -.3 "{&alpha} = .05", placement(12) ) ///
	yline(.05, lcolor(gs10))  name(delta_coh_p, replace)

grc1leg delta_coh_b delta_coh_p
graph export "trend_coh_coh.eps", replace 
